#
# spec file for package palette
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           palette
Version:        4.0.0
Release:        1.13
Summary:        Color palette viewer
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Visualization/Other
URL:            https://github.com/cassidyjames/palette
Source:         https://github.com/cassidyjames/palette/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  AppStream
BuildRequires:  fdupes
BuildRequires:  gettext-runtime >= 0.19.7
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite) >= 5.1.0
BuildRequires:  pkgconfig(gtk+-3.0)
Recommends:     %{name}-lang

%description
A program for viewing and copying colors from Elementary OS.

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.cassidyjames.palette Graphics GTK Viewer
%find_lang com.github.cassidyjames.palette %{name}.lang
%fdupes %{buildroot}/%{_datadir}

# dirlist HiDPI icons (see: hicolor/index.theme)
touch $PWD/dir.lst
_dirlist=$PWD/dir.lst
pushd %{buildroot}
find ./ | while read _list; do
    echo $_list | grep '[0-9]\@[0-9]' || continue
    _path=$(echo $_list | sed 's/[^/]//')
    if ! ls ${_path%/*}; then
        grep -xqs "\%dir\ ${_path%/*}" $_dirlist || echo "%dir ${_path%/*}" >> $_dirlist
    fi
done
popd

%files -f dir.lst
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/com.github.cassidyjames.palette
%{_datadir}/applications/com.github.cassidyjames.palette.desktop
%{_datadir}/glib-2.0/schemas/com.github.cassidyjames.palette.gschema.xml
%{_datadir}/icons/hicolor/*/apps/com.github.cassidyjames.palette.??g
%{_datadir}/metainfo/com.github.cassidyjames.palette.appdata.xml

%files lang -f %{name}.lang

%changelog
* Thu Sep  9 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 4.0.0:
  * Hello, Odin
  * Update for OS 6 and Flatpak
  * Turkish translations thanks to Safak GENISOL
  * Brazilian Portuguese translations thanks to Henrique Andrade
* Sun May 17 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.2.1:
  * Fix Mint and Bubblegum palette colors
  * Add Mint and Bubblegum (#49)
* Wed Feb 19 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.1.7:
  * Remove debian packaging from in-tree
  * Create compress-images.yml
  * Create gettext.yml
  * Create lint.yml
  * Create release.yml
  * Add files via upload (#44)
  * Update .travis.yml
  * Downgrade Node.js to fix builds on Travis CI (#42)
  * Prefer dark (#38)
  * Use real colors again for AppCenter website
* Thu Jan 17 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.1.5:
  * Update com.github.cassidyjames.palette.appdata.xml.in
* Wed Jan  9 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.1.3:
  * Update com.github.cassidyjames.palette.appdata.xml.in
  * Comment out problematic "contact" url
  * Add donation, help, and contact URLs
  * Update es.po (#34)
* Mon Nov 19 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.1.2:
  * Respect system-wide dark preference (#33)
  * Remove desktop screenshot
  * Only reposition on the right quarter of the screen
  * Remove debug, add comments
  * Fewer magic numbers
  * Resize mini window to fit popover
  * Update appdata
  * Purple branding
* Tue Oct 16 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.0.0:
  * Mini mode (#32)
  * Update README.md
  * Color constants (#30)
  * Update com.github.cassidyjames.palette.appdata.xml.in
  * Update az.po
- Add pkgconfig(granite)
* Mon Sep 10 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.1:
  * Cleaned up build system a bit
  * Added Spanish translations to the usage cards
* Wed Aug  1 2018 avvissu@yandex.by
- Update to 2.3.0:
  * Bump version
  * Update icon in README
  * Simpler icon installation
  * New more logical icons (#23)
  * Add 🎨 to keywords (#22)
  * Prep for Juno (#21)
* Sat Jul 14 2018 jengelh@inai.de
- Rectify grammar in description.
* Sun Jul  1 2018 avvissu@yandex.by
- Update to 2.2.0:
  * New Grape colors (#20)
- Switch to metainfo
* Sat Jun 23 2018 avvissu@yandex.by
- Update to 2.1.0:
  * Updated Grape color to match official elementary palette
  * Updated icons to match new Grape color
  * Add translation instructions and update translation link in appdata
* Tue May  8 2018 avvissu@yandex.by
- Update to 2.0.5:
  * Update website
* Sat Apr 21 2018 avvissu@yandex.by
- Update to 2.0.4:
  * Add appdata for 2.0.3 release
* Sat Apr 14 2018 avvissu@yandex.by
- Update to 2.0.2:
  * Update version number
  * Update screenshot
  * Cheat at contrast
  * Right-align and monospce hex
  * Only allow one instance
  * New popover style
  * Better popover styles
  * Update to new icon
  * Switch to Gtk.MenuButton to fix #10
  * fix rivet on 32px
  * New icon, fixes #7
  * Update PO files
  * Add .deskop and appdata to pot
  * Add all the languages!
  * Remove Granite dep from README
  * Update README with links
- Add a new package with translations
* Mon Apr  9 2018 avvissu@yandex.by
- Initial package
